@@ -5,7 +5,7 @@ import time
 from msmart.const import MSGTYPE_ENCRYPTED_REQUEST, MSGTYPE_HANDSHAKE_REQUEST
 from msmart.security import security
 
-VERSION = '0.2.0'
+VERSION = '0.2.1'
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -116,21 +116,24 @@ class lan:
             _LOGGER.info('Got TCP key for {} {}'.format(self.get_socket_info(), tcp_key.hex()))
             # After authentication, don’t send data immediately, so sleep 1s.
             time.sleep(1)
+        else:
+            _LOGGER.error('Authentication failed for {} {}'.format(self.get_socket_info(), tcp_key.hex()))
         return success
 
     def _authenticate(self):
         if not self._token or not self._key:
             raise Exception('missing token key pair')
-        self.authenticate(self._token, self._key)
+        return self.authenticate(self._token, self._key)
 
     def appliance_transparent_send_8370(self, data, msgtype=MSGTYPE_ENCRYPTED_REQUEST):
         # socket_time = time.time() - self._timestamp
         # _LOGGER.debug("Data: {} msgtype: {} len: {} socket time: {}".format(data.hex(), msgtype, len(data), socket_time))
         if self._socket is None or self._tcp_key is None:
             _LOGGER.debug(
-                "Socket {} Closed, Create New Socket".format(self.get_socket_info()))
+                "Socket {} invalid, Create New Socket and Get New tcp_key {}".format(self.get_socket_info(), self._tcp_key))
             self._disconnect()
-            self._authenticate()
+            if self._authenticate() == False:
+                return []
         # copy from data in order to resend data
         original_data = bytearray.copy(data)
         data = self.security.encode_8370(data, msgtype)
@@ -138,6 +141,9 @@ class lan:
         time.sleep(self._retries)
         responses, b = self.request(data)
         _LOGGER.debug("Got responses len: {}".format(len(responses)))
+        if responses[8:13] == b'ERROR':
+            self._disconnect()
+            return [b'ERROR']
         if responses == bytearray(0) and self._retries < 2 and b:
             packets = self.appliance_transparent_send_8370(
                 original_data, msgtype)
