@@ -15,7 +15,7 @@ try:
 except ImportError:
     import xml.etree.ElementTree as ET
 
-VERSION = '0.2.0'
+VERSION = '0.2.1'
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -169,7 +169,7 @@ class MideaDiscovery:
 
     async def get_all(self):
         for i in range(self.amount):
-            _LOGGER.debug("Broadcast message sent: " + str(i))
+            _LOGGER.debug("Broadcast message sent: " + str(i+1))
             await self._broadcast_message()
             tasks = set()
             while True:
