@@ -1,15 +1,15 @@
 # -*- coding: UTF-8 -*-
 import logging
 import urllib
-from Cryptodome.Cipher import AES
-from Cryptodome.Util.Padding import pad, unpad
-from Cryptodome.Util.strxor import strxor
-from Cryptodome.Random import get_random_bytes
+from Crypto.Cipher import AES
+from Crypto.Util.Padding import pad, unpad
+from Crypto.Util.strxor import strxor
+from Crypto.Random import get_random_bytes
 from hashlib import md5, sha256
 from msmart.const import MSGTYPE_ENCRYPTED_REQUEST, MSGTYPE_ENCRYPTED_RESPONSE
 from urllib.parse import urlparse
 
-VERSION = '0.2.0'
+VERSION = '0.2.1'
 _LOGGER = logging.getLogger(__name__)
 appKey = '434a209a5ce141c3b726de067835d7f0'
 signKey = 'xhdiwjnchekd4d512chdjx5d8e4c394D2D7S'
